# -*- coding: UTF-8 -*-
from django.conf.urls import url

from django_datawatch import views

urlpatterns = [
    url(r'^$', views.DashboardView.as_view(), name='django_datawatch_index'),
    url(r'^result/(?P<pk>\d+)/$', views.ResultView.as_view(), name='django_datawatch_result'),
    url(r'^result/(?P<pk>\d+)/acknowledge/$', views.ResultAcknowledgeView.as_view(),
        name='django_datawatch_result_acknowledge'),
    url(r'^result/(?P<pk>\d+)/config/$', views.ResultConfigView.as_view(), name='django_datawatch_result_config'),
    url(r'^result/(?P<pk>\d+)/refresh/$', views.ResultRefreshView.as_view(), name='django_datawatch_result_refresh'),
]



# -*- coding: UTF-8 -*-
from __future__ import unicode_literals

from dateutil import relativedelta
from django.utils import timezone
from django.conf import settings
from django.db import models
from django.utils.encoding import python_2_unicode_compatible
from django.utils.translation import ugettext_lazy as _
from django_extensions.db.fields.json import JSONField
from model_utils.choices import Choices
from model_utils.models import TimeStampedModel

from .monitoring import monitor
from .querysets import CheckQuerySet


class AlreadyAcknowledged(Exception):
    pass


@python_2_unicode_compatible
class Check(TimeStampedModel):
    STATUS = Choices((0, 'unknown', _('Unknown')),
                     (1, 'ok', _('OK')),
                     (2, 'warning', _('Warning')),
                     (3, 'critical', _('Critical')))

    slug = models.TextField(verbose_name=_('Module slug'))
    identifier = models.CharField(max_length=256, verbose_name=_('Identifier'))

    status = models.IntegerField(choices=STATUS,
                                 default=STATUS.unknown, verbose_name=_('Status'))
    config = JSONField(blank=True, verbose_name=_('Configuration'))

    payload_description = models.TextField(verbose_name=_('Payload description'))

    acknowledged_by = models.ForeignKey(to=settings.AUTH_USER_MODEL, null=True,
                                        verbose_name=_('Acknowledged by'),
                                        related_name='acknowledged_by')
    acknowledged_at = models.DateTimeField(null=True, verbose_name=_('Acknowledged at'))
    acknowledged_until = models.DateTimeField(null=True, verbose_name=_('Acknowledged until'))
    acknowledged_reason = models.TextField(blank=True, verbose_name=_('Acknowledge reason'))

    assigned_to_user = models.ForeignKey(to=settings.AUTH_USER_MODEL, null=True,
                                         related_name='assigned_to_user')
    assigned_to_group = models.ForeignKey(to='auth.Group', null=True)

    objects = CheckQuerySet.as_manager()

    class Meta:
        unique_together = ('slug', 'identifier')

    def acknowledge(self, user, days, reason=None, commit=True):
        if self.status in (self.STATUS.warning, self.STATUS.critical) and self.is_acknowledged():
            raise AlreadyAcknowledged()
        self.acknowledged_at = timezone.now()
        self.acknowledged_by = user
        self.acknowledged_until = timezone.now() + relativedelta.relativedelta(days=days)
        self.acknowledged_reason = reason or ''
        if commit:
            self.save(update_fields=['acknowledged_at', 'acknowledged_by', 'acknowledged_until', 'acknowledged_reason'])

    def is_acknowledged(self):
        return self.acknowledged_until and self.acknowledged_until >= timezone.now()

    def __str__(self):
        return self.slug

    def get_check_instance(self):
        return monitor.get_check_class(self.slug)()

    def get_payload(self):
        return self.get_check_instance().get_payload(self.identifier)


@python_2_unicode_compatible
class CheckExecution(models.Model):
    slug = models.TextField(verbose_name=_('Check module slug'), unique=True)
    last_run = models.DateTimeField(verbose_name=_('Last run'))

    def __str__(self):
        return '%s on %s' % (self.slug, self.last_run)



# -*- coding: UTF-8 -*-
import logging

from braces.views import PermissionRequiredMixin, LoginRequiredMixin
from django.core.urlresolvers import reverse_lazy
from django.utils.translation import gettext_lazy as _
from django.views.generic.base import RedirectView
from django.views.generic.detail import DetailView, SingleObjectMixin
from django.views.generic.edit import UpdateView, FormView
from django.contrib import messages

from django_datawatch import forms
from django_datawatch.common.views import FilteredListView
from django_datawatch.models import Check
from django_datawatch.settings import ddw_settings
from django_datawatch.tasks import django_datawatch_run

logger = logging.getLogger(__name__)


class DashboardView(LoginRequiredMixin, PermissionRequiredMixin, FilteredListView):
    form_class = forms.ResultFilterForm
    permission_required = 'django_datawatch.view'
    template_name = 'django_datawatch/dashboard.html'
    context_object_name = 'results'

    def get_form_kwargs(self):
        kwargs = super(DashboardView, self).get_form_kwargs()
        kwargs.update(dict(user=self.request.user))
        return kwargs

    def get_queryset(self):
        if self.queryset is None:
            self.queryset = Check.objects.all().order_by('-status')
        return self.queryset

    def get_context_data(self, **kwargs):
        ctx = super(DashboardView, self).get_context_data(**kwargs)
        ctx.update(dict(check=Check))
        return ctx


class ResultView(LoginRequiredMixin, PermissionRequiredMixin, DetailView):
    permission_required = 'django_datawatch.view'
    model = Check
    template_name = 'django_datawatch/detail.html'

    def __init__(self, *args, **kwargs):
        super(ResultView, self).__init__(*args, **kwargs)
        self.check_instance = None

    def get_check_instance(self):
        if not self.check_instance:
            self.check_instance = self.object.get_check_instance()
        return self.check_instance

    def get_context_data(self, **kwargs):
        kwargs.update(result=self.object)
        ctx = super(ResultView, self).get_context_data(**kwargs)
        ctx.update(self.get_check_instance().get_context_data(self.object))
        return ctx

    def get_template_names(self):
        template_names = super(ResultView, self).get_template_names()
        check_template = self.get_check_instance().get_template_name()
        if check_template:
            return [check_template] + template_names
        return template_names


class ResultAcknowledgeView(LoginRequiredMixin, PermissionRequiredMixin, UpdateView):
    permission_required = 'django_datawatch.acknowledge'
    form_class = forms.AcknowledgeForm
    model = Check
    template_name = 'django_datawatch/form.html'

    def get_form_kwargs(self):
        kwargs = super(ResultAcknowledgeView, self).get_form_kwargs()
        kwargs['user'] = self.request.user
        return kwargs

    def get_success_url(self):
        return reverse_lazy('django_datawatch_index')

    def get_context_data(self, **kwargs):
        ctx = super(ResultAcknowledgeView, self).get_context_data(**kwargs)
        ctx.update(dict(action=_('Acknowledge')))
        return ctx

    def form_valid(self, form):
        response = super(ResultAcknowledgeView, self).form_valid(form)
        messages.add_message(self.request, messages.INFO, _('Check has been successfully acknowledged'))
        return response


class ResultConfigView(LoginRequiredMixin, PermissionRequiredMixin, SingleObjectMixin, FormView):
    permission_required = 'django_datawatch.config'
    model = Check
    template_name = 'django_datawatch/form.html'

    def __init__(self, **kwargs):
        self.object = None
        super(ResultConfigView, self).__init__(**kwargs)

    def get(self, request, *args, **kwargs):
        self.object = self.get_object()
        return super(ResultConfigView, self).get(request, *args, **kwargs)

    def post(self, request, *args, **kwargs):
        self.object = self.get_object()
        return super(ResultConfigView, self).post(request, *args, **kwargs)

    def get_form_class(self):
        return self.object.get_check_instance().get_form_class()

    def get_form_kwargs(self):
        kwargs = super(ResultConfigView, self).get_form_kwargs()
        if self.object.config:
            kwargs.update(dict(initial=self.object.config))
        return kwargs

    def get_success_url(self):
        return reverse_lazy('django_datawatch_result', kwargs=dict(pk=self.object.pk))

    def get_context_data(self, **kwargs):
        ctx = super(ResultConfigView, self).get_context_data(**kwargs)
        ctx.update(dict(action=_('Save')))
        return ctx

    def form_valid(self, form):
        form.save(instance=self.object)
        check = self.object.get_check_instance()

        django_datawatch_run.apply(kwargs=dict(check_slug=check.slug, identifier=check.get_identifier(self.object)),
                                   queue=ddw_settings.QUEUE_NAME)
        return super(ResultConfigView, self).form_valid(form)


class ResultRefreshView(LoginRequiredMixin, PermissionRequiredMixin, SingleObjectMixin, RedirectView):
    permission_required = 'django_datawatch.refresh'
    permanent = False
    model = Check

    def __init__(self, **kwargs):
        super(ResultRefreshView, self).__init__(**kwargs)
        self.kwargs = dict()
        self.object = None

    def get(self, request, *args, **kwargs):
        self.object = self.get_object()
        response = super(ResultRefreshView, self).get(request, *args, **kwargs)
        check = self.object.get_check_instance()
        django_datawatch_run.apply(kwargs=dict(check_slug=check.slug, identifier=check.get_identifier(self.object)),
                                   queue=ddw_settings.QUEUE_NAME)
        messages.add_message(request, messages.INFO, _('Result has been refreshed'))
        return response

    def get_redirect_url(self, *args, **kwargs):
        return reverse_lazy('django_datawatch_result', kwargs=dict(pk=self.object.pk))



# -*- coding: UTF-8 -*-
from __future__ import unicode_literals

from django.contrib import admin

from django_datawatch.models import Check, CheckExecution


@admin.register(Check)
class CheckAdmin(admin.ModelAdmin):
    list_display = ('slug', 'identifier', 'status')
    search_fields = ('slug', 'identifier', 'payload_description')
    list_filter = ('status', )


@admin.register(CheckExecution)
class CheckExecutionAdmin(admin.ModelAdmin):
    list_display = ('slug', 'last_run')
    search_fields = ('slug', )



# -*- coding: utf-8 -*-
# Generated by Django 1.9.8 on 2016-09-03 17:44
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import django_extensions.db.fields.json
import model_utils.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('auth', '0007_alter_validators_add_error_messages'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Check',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('slug', models.TextField(verbose_name='Module slug')),
                ('identifier', models.CharField(max_length=256, verbose_name='Identifier')),
                ('status', models.IntegerField(choices=[(0, 'Unknown'), (1, 'OK'), (2, 'Warning'), (3, 'Danger')], default=0, verbose_name='Status')),
                ('config', django_extensions.db.fields.json.JSONField(blank=True, default=dict, verbose_name='Configuration')),
                ('payload_description', models.TextField(verbose_name='Payload description')),
                ('acknowledged_at', models.DateTimeField(null=True, verbose_name='Acknowledged at')),
                ('acknowledged_until', models.DateTimeField(null=True, verbose_name='Acknowledged until')),
                ('acknowledged_by', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='acknowledged_by', to=settings.AUTH_USER_MODEL, verbose_name='Acknowledged by')),
                ('assigned_to_group', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='auth.Group')),
                ('assigned_to_user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='assigned_to_user', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.AlterUniqueTogether(
            name='check',
            unique_together=set([('slug', 'identifier')]),
        ),
    ]



# -*- coding: UTF-8 -*-
import logging

from django.core.management.base import BaseCommand

from django_datawatch.monitoring import Scheduler


class Command(BaseCommand):
    def handle(self, *args, **options):
        Scheduler().run_checks()



# -*- coding: UTF-8 -*-
from django.conf import settings


USER_SETTINGS = getattr(settings, 'DJANGO_DATAWATCH', {})


DEFAULT_SETTINGS = dict(
    QUEUE_NAME='django_datawatch'
)

ddw_settings = DEFAULT_SETTINGS.copy()
ddw_settings.update(USER_SETTINGS)
ddw_settings = type('settings', (object, ), ddw_settings)



# -*- coding: UTF-8 -*-
from django.views.generic.edit import FormMixin
from django.views.generic.list import ListView


class FilteredListView(FormMixin, ListView):
    def get_form_kwargs(self):
        return {
          'initial': self.get_initial(),
          'prefix': self.get_prefix(),
          'data': self.request.GET or None
        }

    def get(self, request, *args, **kwargs):
        self.object_list = self.get_queryset()

        form = self.get_form(self.get_form_class())
        self.object_list = form.filter_queryset(request, self.object_list)

        context = self.get_context_data(form=form, object_list=self.object_list)
        return self.render_to_response(context)



# -*- coding: utf-8 -*-
# Generated by Django 1.9.8 on 2016-09-04 09:09
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_datawatch', '0002_auto_20160903_2149'),
    ]

    operations = [
        migrations.CreateModel(
            name='CheckExecution',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.TextField(unique=True, verbose_name='Check module slug')),
                ('last_run', models.DateTimeField(verbose_name='Last run')),
            ],
        ),
        migrations.AlterField(
            model_name='check',
            name='acknowledged_reason',
            field=models.TextField(blank=True, verbose_name='Acknowledge reason'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.8 on 2016-09-03 21:49
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_datawatch', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='check',
            name='acknowledged_reason',
            field=models.TextField(blank=True, verbose_name='Acknowledged until'),
        ),
        migrations.AlterField(
            model_name='check',
            name='status',
            field=models.IntegerField(choices=[(0, 'Unknown'), (1, 'OK'), (2, 'Warning'), (3, 'Critical')], default=0, verbose_name='Status'),
        ),
    ]



# -*- coding: UTF-8 -*-
from __future__ import unicode_literals

import logging

from collections import defaultdict

from dateutil.relativedelta import relativedelta
from django.utils import timezone
from django.utils.module_loading import autodiscover_modules
from django.db.models import signals

from django_datawatch.settings import ddw_settings

logger = logging.getLogger(__name__)


class MonitoringHandler(object):
    def __init__(self):
        self._registered_checks = {}
        self._related_models = defaultdict(list)

    def autodiscover_checks(self, module_name='checks'):
        autodiscover_modules(module_name)

    def register(self, check_class):
        slug = self.get_slug(check_class.__module__, check_class.__name__)
        self._registered_checks[slug] = check_class
        check = check_class()
        if hasattr(check, 'trigger_update'):
            for method_name, model in check.trigger_update.items():
                if not hasattr(check, 'get_%s_payload' % method_name):
                    logger.warning('Update trigger defined without implementing .get_*_payload()')
                    continue

                model_uid = make_model_uid(model)
                if model_uid in self._related_models:
                    signals.post_save.connect(run_checks, sender=model)
                self._related_models[model_uid].append(check_class)

        return check_class

    def get_all_registered_checks(self):
        return self._registered_checks.values()

    @property
    def checks(self):
        for slug in self._registered_checks.keys():
            yield slug

    def get_check_class(self, slug):
        if slug in self._registered_checks:
            return self._registered_checks[slug]
        return None

    def get_checks_for_model(self, model):
        model_uid = make_model_uid(model)
        if model_uid in self._related_models:
            return self._related_models[model_uid]
        return None

    def get_slug(self, module, class_name):
        return u'{}.{}'.format(module, class_name)

monitor = MonitoringHandler()


class Scheduler(object):
    def run_checks(self):
        from django_datawatch.models import CheckExecution

        now = timezone.now()
        checks = monitor.get_all_registered_checks()
        executions = dict([(obj.slug, obj.last_run) for obj in CheckExecution.objects.all()])

        for check in checks:
            # check should not be run automatically
            if not hasattr(check, 'run_every') or not isinstance(check.run_every, relativedelta):
                continue

            # shall the check be run again?
            check_instance = check()
            if check_instance.slug in executions:
                if now + check.run_every < executions[check_instance.slug]:
                    continue

            # enqueue the check and save execution state
            logger.info('check %s issued for refresh', check_instance.slug)
            check_instance.run()
            CheckExecution.objects.update_or_create(slug=check_instance.slug, defaults=dict(last_run=now))


def make_model_uid(model):
    """
    Returns an uid that will identify the given model class.

    :param model: model class
    :return: uid (string)
    """
    return "%s.%s" % (model._meta.app_label, model.__name__)


def run_checks(sender, instance, created, raw, using, **kwargs):
    """
    Re-execute checks related to the given sender model, only for the updated instance.

    :param sender: model
    :param kwargs:
    """
    from django_datawatch.tasks import django_datawatch_run
    checks = monitor.get_checks_for_model(sender) or []
    for check_class in checks:
        check = check_class()
        payload = check.get_payload(instance)
        if not payload:
            continue
        django_datawatch_run().apply(
            kwargs=dict(check_slug=check.slug, identifier=check.get_identifier(payload)),
            queue=ddw_settings.QUEUE_NAME)



# -*- coding: UTF-8 -*-
from __future__ import unicode_literals

from celery import shared_task
from celery.utils.log import get_task_logger
from celery.schedules import crontab
from celery.task.base import PeriodicTask

from django_datawatch.settings import ddw_settings
from django_datawatch.monitoring import monitor

logger = get_task_logger(__name__)


@shared_task
def django_datawatch_enqueue(check_slug, *args, **kwargs):
    logger.debug('enqueuing checks for %s', check_slug)
    check = monitor.get_check_class(check_slug)()

    for payload in check.generate():
        identifier = check.get_identifier(payload)
        django_datawatch_run.apply_async(kwargs=dict(check_slug=check_slug, identifier=identifier),
                                         queue=ddw_settings.QUEUE_NAME)


@shared_task
def django_datawatch_run(check_slug, identifier, *args, **kwargs):
    logger.debug('running check %s for identifier %s', check_slug, identifier)
    check = monitor.get_check_class(check_slug)()
    payload = check.get_payload(identifier)
    return check.handle(payload)


class DatawatchScheduler(PeriodicTask):
    run_every = crontab(minute=0, hour=0)

    def run(self, *args, **kwargs):
        for check_slug in monitor.checks:
            django_datawatch_enqueue.apply_async(kwargs=dict(check_slug=check_slug), queue=ddw_settings.QUEUE_NAME)



# -*- coding: UTF-8 -*-
from __future__ import unicode_literals
import logging

from django import forms

from django_datawatch.settings import ddw_settings
from django_datawatch.tasks import django_datawatch_enqueue
from django_datawatch.models import Check
from django_datawatch.monitoring import monitor

logger = logging.getLogger(__name__)


class BaseCheckForm(forms.Form):
    def save(self, instance):
        instance.config = self.cleaned_data
        instance.save(update_fields=['config'])
        return instance


class BaseCheck(object):

    """
    Any check should inherits from `BaseCheck` and should implements `.generate(self)`
    and `.check(self, payload)` methods.

    Optionally, you can implements `.get_assigned_user(self, payload)` (resp. `.get_assigned_group(self, payload)`)
    to define to which user (resp. group) the system had to assign the check result.
    """

    config_form = None
    title = ''

    def __init__(self):
        self.slug = monitor.get_slug(self.__module__, self.__class__.__name__)

    def run(self):
        django_datawatch_enqueue.apply_async(kwargs=dict(check_slug=self.slug), queue=ddw_settings.QUEUE_NAME)

    def handle(self, payload):
        # check result
        try:
            old_status = Check.objects.get(slug=self.slug, identifier=self.get_identifier(payload)).status
        except Check.DoesNotExist:
            old_status = None
        status = self.check(payload)
        unacknowledge = old_status in [Check.STATUS.warning, Check.STATUS.critical] and status == Check.STATUS.ok
        self.save(payload, status, unacknowledge=unacknowledge)

    def get_config(self, payload):
        try:
            check_result = Check.objects.get(slug=self.slug, identifier=self.get_identifier(payload))

            # check has a configuration
            if check_result.config:
                return check_result.config
        except Check.DoesNotExist:
            pass

        # get default config from form initial values
        form = self.get_form_class()()
        return {name: field.initial for name, field in form.fields.items()}

    def get_form(self, payload):
        return self.get_form_class()(**self.get_config(payload))

    def get_form_class(self):
        return self.config_form

    def save(self, payload, result, unacknowledge=False):
        defaults = {
            'status': result,
            'assigned_to_user': self.get_assigned_user(payload, result),
            'assigned_to_group': self.get_assigned_group(payload, result),
            'payload_description': self.get_payload_description(payload)
        }

        # save the check
        dataset, created = Check.objects.get_or_create(
            slug=self.slug, identifier=self.get_identifier(payload),
            defaults=defaults)

        # update existing dataset
        if not created:
            for (key, value) in defaults.items():
                setattr(dataset, key, value)
            if unacknowledge:
                dataset.acknowledge_by = None
                dataset.acknowledge_at = None
                dataset.acknowledge_until = None
            dataset.save()

    def generate(self):
        """
        yield items to run check for
        """
        raise NotImplementedError(".generate() should be overridden")

    def check(self, payload):
        """
        :param payload: the payload to run the check for
        :return:
        """
        raise NotImplementedError(".check() should be overridden")

    def get_identifier(self, payload):
        raise NotImplementedError(".get_identifier() should be overridden")

    def get_payload_description(self, payload):
        return str(payload)

    def get_assigned_user(self, payload, result):
        return None

    def get_assigned_group(self, payload, result):
        return None

    def get_context_data(self, payload):
        return dict()

    def get_title(self):
        return self.title

    def get_template_name(self):
        if hasattr(self, 'template_name'):
            return self.template_name
        return None



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models
from django.db.models.aggregates import Count
from django.db.models.expressions import Case, When, Value
from django.db.models.query_utils import Q
from django.utils import timezone


class CheckQuerySet(models.QuerySet):
    def for_user(self, user):
        return self.filter(Q(assigned_to_group__isnull=True) | Q(assigned_to_group__in=user.groups.all()),
                           Q(assigned_to_user__isnull=True) | Q(assigned_to_user=user))

    def failed(self):
        return self.exclude(status__in=(self.model.STATUS.unknown, self.model.STATUS.ok))

    def ok(self):
        return self.filter(status=self.model.STATUS.ok)

    def unknown(self):
        return self.filter(status=self.model.STATUS.unknown)

    def unacknowledged(self):
        return self.exclude(acknowledged_until__gt=timezone.now())

    def with_status_name(self):
        case = Case(output_field=models.CharField())
        for status_value in self.model.STATUS._db_values:
            case.cases.append(
                When(status=status_value, then=Value(str(self.model.STATUS[status_value]))),
            )
        return self.annotate(status_name=case)

    def get_stats(self):
        return self.values('status').annotate(amount=Count('id')).with_status_name()



# -*- coding: UTF-8 -*-
from setuptools import setup, find_packages


setup(
    name='django-datawatch',
    packages=find_packages(exclude=['example*']),
    version='0.1.4',
    description='Django Datawatch runs automated data checks in your Django installation',
    author='Jens Nistler <opensource@jensnistler.de>, Bogdan Radko',
    author_email='opensource@regiohelden.de',
    install_requires=[
        'celery>=3.1.23',
        'Django>=1.9',
        'django-braces>=1.9.0',
        'django-extensions>=1.6.7',
        'django-model-utils>=2.5',
        'python-dateutil>=2.5.3',
        'django-bootstrap3>=7.0.1',
    ],
    license='MIT',
    url='https://github.com/RegioHelden/django-datawatch',
    download_url='',
    keywords=['django', 'monitoring', 'datawatch', 'check', 'checks'],
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Development Status :: 4 - Beta",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: Software Development",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: System :: Monitoring",
    ]
)



# -*- coding: UTF-8 -*-
from __future__ import unicode_literals, print_function

from django.apps import AppConfig
from django.contrib import admin
from django_datawatch.monitoring import monitor


class DjangoDatawatchConfig(AppConfig):
    name = 'django_datawatch'
    verbose_name = "Django datawatch"

    def ready(self):
        super(DjangoDatawatchConfig, self).ready()

        monitor.autodiscover_checks()
        admin.autodiscover()
